
#include <stdint.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <avr/io.h>
#include <util/delay.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>

#include <tool.h>
#include <uart.h>
#include <i2c.h>
#include <disp.h>
#include <relay.h>

#include <contr.h>

int main(void) {
    uart_init();
    i2c_init();
    uartio_init();
    disp_init();

    atten_init();
    relaytx_init();
    relay10m_init();
    relay20m_init();
    relay40m_init();
    relay80m_init();
    buzzer_init();
    fan_init();

    relaytx_off();
    atten_off();
    relay10m_off();
    relay20m_off();
    relay40m_off();
    relay80m_off();
    buzzer_off();
    fan_off();

    contr_init();
    contr_setup();
    sei();
    contr_main();
    return 0;
}
